@@ -5,6 +5,7 @@
 Test pandas functionality.
 """
 
+import pathlib
 import random
 from collections import OrderedDict
 from datetime import datetime
@@ -12,7 +13,8 @@ from itertools import product
 from typing import Dict, List, Optional, Tuple, Union, cast
 
 import pandas as pd
-from pytest import mark, xfail
+from pandas.testing import assert_frame_equal
+from pytest import importorskip, mark
 from sqlalchemy import create_engine
 
 _possible_args = OrderedDict(
@@ -85,7 +87,6 @@ table_name = "test_read"
 
 # Perform the test twice:
 # Once for reading the table name (testing reflection),
-@mark.xfail(reason="reflection not yet supported in duckdb")
 @mark.parametrize(params_strings["read_sql"], params["read_sql"])
 def test_read_sql_reflection(
     chunksize: Tuple[Optional[int]],
@@ -111,9 +112,29 @@ def run_query(query: str, chunksize: Optional[int]) -> None:
     if chunksize is None:
         assert len(chunks[0]) == sample_rowcount
     else:
-        xfail(reason="This will fail until the next duckdb release")
+        importorskip("duckdb", "0.5.0")
 
         # Assert that the chunks are the size specified.
         assert len(chunks[0]) == chunksize
         # Assert that the expected number of chunks was returned.
         assert (sample_rowcount / chunksize) == len(chunks)
+
+
+def test_read_sql_duckdb_table(tmp_path: pathlib.Path) -> None:
+    import duckdb
+
+    db = str(tmp_path / "test_db.duckdb")
+    con = duckdb.connect(database=db, read_only=False)
+    df = pd.DataFrame(
+        {"a": [1, 2, 3, 4], "b": [0.1, 0.2, 0.3, 0.4], "c": ["a", "b", "c", "d"]}
+    )
+    con.register("df_view", df)
+    con.execute("CREATE TABLE test_data AS SELECT * FROM df_view;")
+    con.close()
+
+    engine = create_engine(f"duckdb:///{db}")
+
+    result = pd.read_sql("SELECT * FROM test_data", engine)
+    assert_frame_equal(result, df)
+    result = pd.read_sql("test_data", engine)
+    assert_frame_equal(result, df)
